@@ -13,7 +13,7 @@ import termios
 import time
 from contextlib import contextmanager
 
-__version__ = 'cplay-ng 5.2.0'
+__version__ = 'cplay-ng 5.3.0'
 
 AUDIO_EXTENSIONS = [
     'mp3', 'ogg', 'oga', 'opus', 'flac', 'm4a', 'm4b', 'wav', 'mid', 'wma'
@@ -78,7 +78,7 @@ def str_match(query, s):
     return all(q in s.lower() for q in query.lower().split())
 
 
-def resize(*args):
+def resize(*_args):
     os.write(app.resize_out, b'.')
 
 
@@ -87,12 +87,20 @@ def get_socket(path):
         try:
             sock = socket.socket(family=socket.AF_UNIX)
             sock.connect(path)
-            return sock
         except (FileNotFoundError, ConnectionRefusedError):
             time.sleep(0.1)
+        else:
+            return sock
 
 
-@functools.lru_cache()
+@functools.cache
+def get_mpv_version():
+    p = subprocess.run(['mpv', '--version'], stdout=subprocess.PIPE)
+    s = p.stdout.split(b' ', 2)[1].decode()
+    return tuple(int(i) for i in s.split('.'))
+
+
+@functools.lru_cache
 def relpath(path):
     if path.startswith('http'):
         return path
@@ -148,7 +156,7 @@ class Player:
         self._proc = subprocess.Popen(
             [
                 'mpv',
-                '--input-ipc-server=%s' % self.socket_path,
+                f'--input-ipc-server={self.socket_path}',
                 '--idle',
                 '--audio-display=no',
                 '--replaygain=track',
@@ -212,11 +220,18 @@ class Player:
             return
         self.is_playing = True
         self._playing += 1
-        self._ipc('loadfile', self.path, 'replace', 'start=%i' % self.position)
+        if get_mpv_version() > (0, 38, 0):
+            self._ipc('loadfile', self.path, 'replace', 0, 'start=%i' % self.position)
+        else:
+            self._ipc('loadfile', self.path, 'replace', 'start=%i' % self.position)
 
     def play(self, path):
-        self.path = path
-        self.position = 0
+        if path and (m := re.match(r'^(http.*)#t=([0-9]+)$', path)):
+            self.path = m[1]
+            self.position = float(m[2])
+        else:
+            self.path = path
+            self.position = 0
         self.length = 0
         self._seek_step = 0
         self._play()
@@ -334,13 +349,13 @@ class List:
                 attr |= curses.A_REVERSE
             if self.position + i == self.active:
                 attr |= curses.A_BOLD
-            item = self.format_item(item)
-            item = space_between('  ' + item, '', app.cols)
-            yield (item, attr)
-        for i in range(max(0, self.rows - len(items))):
+            s_item = self.format_item(item)
+            s_item = space_between('  ' + s_item, '', app.cols)
+            yield (s_item, attr)
+        for _i in range(max(0, self.rows - len(items))):
             yield ''
 
-    def process_key(self, key):
+    def process_key(self, key):  # noqa: C901
         if key in [curses.KEY_DOWN, 'j']:
             self.move_cursor(1)
         elif key in [curses.KEY_UP, 'k']:
@@ -398,7 +413,6 @@ class Filelist(List):
             title += 'search "%s"/' % self.rsearch_str
         return title
 
-    @functools.lru_cache()
     def format_item(self, item):
         s = super().format_item(item)
         ext = get_ext(item)
@@ -411,7 +425,6 @@ class Filelist(List):
             self.path = path
             os.chdir(path)
             relpath.cache_clear()
-            self.format_item.cache_clear()
             self.search_cache = []
         self.all_items = []
         self.rsearch_str = ''
@@ -460,28 +473,27 @@ class Filelist(List):
         self.rsearch_str = query
         self.set_cursor(self.cursor)
 
+    def activate(self, item):
+        ext = item.rsplit('.', 1)[-1]
+        if os.path.isdir(item):
+            self.set_path(item)
+        elif ext in AUDIO_EXTENSIONS:
+            playlist.active = -1
+            player.play(item)
+        elif ext == 'm3u':
+            playlist.load(item)
+            app.toggle_tabs()
+
     def process_key(self, key):
         if key == 'a':
-            if not self.items:
-                return True
-            if playlist.add(self.items[self.cursor]):
+            if self.items and playlist.add(self.items[self.cursor]):
                 self.move_cursor(1)
         elif key == 's':
             app.input.start('search: ', on_input=self.filter)
             self.filter(self.rsearch_str)
         elif key == '\n':
-            if not self.items:
-                return True
-            item = self.items[self.cursor]
-            ext = item.rsplit('.', 1)[-1]
-            if os.path.isdir(item):
-                self.set_path(item)
-            elif ext in AUDIO_EXTENSIONS:
-                playlist.active = -1
-                player.play(item)
-            elif ext == 'm3u':
-                playlist.load(item)
-                app.toggle_tabs()
+            if self.items:
+                self.activate(self.items[self.cursor])
         elif key == curses.KEY_BACKSPACE:
             if self.rsearch_str:
                 self.set_path(self.path)
@@ -590,7 +602,7 @@ class Playlist(List):
 
     def add_dir(self, path):
         count = 0
-        for p, ext, is_dir in listdir(path):
+        for p, _ext, _is_dir in listdir(path):
             count += self.add(p, recursive=True)
         return count
 
@@ -598,8 +610,8 @@ class Playlist(List):
         count = 0
         dirname = os.path.dirname(path)
         with open(path, errors='replace') as fh:
-            for line in fh:
-                line = line.strip()
+            for _line in fh:
+                line = _line.strip()
                 if not line or line[0] == '#':
                     continue
                 if not re.match(r'^(/|https?://)', line):
@@ -608,7 +620,7 @@ class Playlist(List):
                 count += 1
         return count
 
-    def add(self, path, recursive=False):
+    def add(self, path, *, recursive=False):
         ext = path.rsplit('.', 1)[-1]
         if os.path.isdir(path):
             return self.add_dir(path)
@@ -633,10 +645,10 @@ class Playlist(List):
                     fh.write('%s\n' % item)
                 self.path = path
                 self.items_written = self.items.copy()
-        except IOError:
+        except OSError:
             pass
 
-    def process_key(self, key):
+    def process_key(self, key):  # noqa: C901
         if key == 'm':
             self.move_item(1)
         elif key == 'M':
@@ -724,13 +736,13 @@ class Application:
         else:
             status = ''
 
-        counter = '%s / %s' % (
+        counter = ' / '.join([
             format_time(player.position),
             format_time(player.length),
-        )
+        ])
         yield space_between(status, counter, self.cols)
 
-    def render(self, force=False):
+    def render(self, *, force=False):
         lines = list(self._render())
         try:
             for i, line in enumerate(lines):
@@ -743,8 +755,9 @@ class Application:
                 screen.move(i, 0)
                 screen.clrtoeol()
                 if isinstance(line, str):
-                    line = (line, 0)
-                screen.insstr(i, 0, *line)
+                    screen.insstr(i, 0, line, 0)
+                else:
+                    screen.insstr(i, 0, *line)
             # make sure cursor is in a meaningful position for a11y
             screen.move(self.tab.cursor - self.tab.position + 2, 0)
             screen.refresh()
@@ -752,7 +765,7 @@ class Application:
             pass
         self.old_lines = lines
 
-    def process_key(self, key):
+    def process_key(self, key):  # noqa: C901
         if self.input.process_key(key):
             pass
         elif self.tab.process_key(key):
@@ -790,7 +803,7 @@ class Application:
                 player.finish_seek()
 
                 timeout = 0.5 if player.is_playing else None
-                for key, mask in sel.select(timeout):
+                for key, _mask in sel.select(timeout):
                     if key.fileobj is self.resize_in:
                         os.read(self.resize_in, 8)
                         self.on_resize()
@@ -816,10 +829,10 @@ screen = curses.initscr()
 
 
 def main():
-    screen.keypad(True)
+    screen.keypad(True)  # noqa: FBT003
     curses.cbreak()
     curses.noecho()
-    curses.meta(True)
+    curses.meta(True)  # noqa: FBT003
     curses.curs_set(0)
 
     signal.signal(signal.SIGWINCH, resize)
